# frozen_string_literal: true

require "active_support"
require "active_support/core_ext"
require "colorize"
require "fileutils"
require "gems"
require "highline"
require "json"
require "net/http"
require "open3"
require "psych"
require "rubygems"
require "securerandom"
require "tmpdir"
require "uri"
require "renuo/cli/version"

Dir[File.expand_path("cli/helpers/*.rb", __dir__)].each { |f| require f }

def agree(question)
  question += " [y/n]" if question
  super
end

# :nocov:
module Renuo
  class Cli
    module Commands; end
    module Services; end

    # include CommandHelper

    def start
      require "commander/import"

      program :version, Renuo::Cli::VERSION
      program :description, "Renuo CLI"
      update

      Dir[File.expand_path("cli/{commands,services}/*.rb", __dir__)].each { |f| require f }
    end

    private

    def update
      info = Gems.info Renuo::Cli::NAME
      return unless Gem::Version.new(Renuo::Cli::VERSION) < Gem::Version.new(info["version"])

      say "You are running the version #{Renuo::Cli::VERSION} but the brand new #{info["version"]} is available. 🎉"

      if agree("Why don't you update with `gem update renuo-cli`? I can run it for you. 💪")
        system("gem update #{Renuo::Cli::NAME}")
        abort "Nice! I updated myself. 🤩 Now you can run the command again."
      end

      abort("Good. Just do it yourself then...😒")
    end
  end
end
# :nocov:
