# frozen_string_literal: true

class Renuo::Cli::Commands::ConfigureSentry
  ADMIN_EMAIL = "admin@renuo.ch"

  command "configure-sentry" do |c|
    c.syntax = "renuo configure-sentry [project-name] [SENTRY_DSN]"
    c.summary = "Generates the script necessary to setup sentry on Heroku."
    c.description = "Generates the script necessary to setup sentry on Heroku."
    c.example "renuo configure-sentry myproject https://randomkey@sentry.io/11223344",
              "generates the command to configure sentry for myproject on Heroku"
    c.action { |args| new.run(args) }
  end

  def run(args)
    project_name = args[0]
    sentry_dsn = args[1]
    abort(">> No project name given.") unless project_name
    abort(">> No sentry DSN name given.") unless sentry_dsn

    say "# Commands to setup Sentry on Heroku\n".colorize :green
    ENVIRONMENTS.each { |env| print_environment_commands(env, project_name, sentry_dsn) }
  end

  private

  def print_environment_commands(env, project_name, sentry_dsn)
    heroku_name = "#{project_name}-#{env}"
    say "heroku config:set SENTRY_DSN=#{sentry_dsn} --app #{heroku_name}"
    say "heroku config:set SENTRY_ENVIRONMENT=#{env} --app #{heroku_name}"
    say "heroku labs:enable runtime-dyno-metadata --app #{heroku_name}"
  end
end
