# frozen_string_literal: true

class Renuo::Cli::Commands::CreateHerokuApp
  ADMIN_EMAIL = "operations@renuo.ch"

  command "create-heroku-app" do |c|
    c.syntax = "renuo create-heroku-app <application-name>"
    c.summary = "Generates the script necessary to setup an application on Heroku."
    c.description = "Generates the script necessary to setup an application on Heroku."
    c.example "renuo create-heroku-app hello", "generates the command to create hello on Heroku"
    c.action { |args| new.run(args) }
  end

  def run(args)
    project_name = args[0]
    abort(">> Project name must be between 2 and 22 characters.") unless project_name&.length&.between?(2, 22)

    say "# Commands to setup your Heroku application\n".colorize :green
    ENVIRONMENTS.each  { |env| print_environment_commands(env, project_name) }
    print_pipelines_commands(project_name)
  end

  private

  def print_environment_commands(env, project_name)
    heroku_name = "#{project_name}-#{env}"
    say "heroku apps:create --region eu #{heroku_name} -t staff"
    say "heroku domains:add #{heroku_name}.renuoapp.ch --app #{heroku_name}"
    say "heroku domains:add #{project_name}-#{MASTER}.renuoapp.ch --app #{heroku_name}" if env == MAIN
    say "heroku addons:create heroku-postgresql  --app #{heroku_name}"
    say "heroku labs:enable runtime-dyno-metadata --app #{heroku_name}"
    say "heroku pg:backups:schedule DATABASE_URL --at '02:00 Europe/Zurich' --app #{heroku_name}"
  end

  def print_pipelines_commands(project_name)
    say "heroku pipelines:create #{project_name} --app #{project_name}-#{MAIN} -s production -t staff"
    say "heroku pipelines:add #{project_name} --app #{project_name}-#{DEVELOP} -s staging"
    say "\n"
  end
end
