# frozen_string_literal: true

class Renuo::Cli::Commands::CreateNewLogins
  include CommandHelper

  LOGINS = [{ name: "Sentry", sign_up_url: "https://sentry.io/organizations/renuo/members/new/",
              steps: ["Click on add new Member"] },
            { name: "NewRelic", sign_up_url: "https://rpm.newrelic.com/",
              steps: ["Click on Renuo", "Account Settings > Add user"] }].freeze

  command "create-new-logins" do |c|
    c.syntax = "renuo create-new-logins"
    c.summary = "Guides you through the sign up pages for Sentry, NewRelic and Gemnasium"
    c.description = "Guides you through the sign up pages for Sentry, NewRelic and Gemnasium"
    c.example "renuo create-new-logins", "creates new logins"
    c.action { new.run }
  end

  def run
    LOGINS.each do |login|
      say login[:name].yellow
      login[:steps].each_with_index do |step, index|
        say "\t#{index + 1}. #{step}"
      end
      open_site login[:sign_up_url]
    end
    say "every thing is set up".green
  end

  private

  def open_site(website)
    open_path(website)
    wait_to_continue
  end

  def wait_to_continue
    system "read -n 1 -s -p 'Press any key to continue...'"
    say "\n"
  end
end
