# frozen_string_literal: true

class Renuo::Cli::Commands::DisplayName
  include CommandHelper

  HEROKU_APP_NAME = "-a renuo-dashboard-main"
  HEROKU_CLI = "heroku run"
  RENUO_CLI = "rails renuo:welcome"
  SLIDES = "https://docs.google.com/presentation/d/1mPhQjArZnlUWUa2ik5R9IlGmdCKCwc2_H8Qq-AWgV-A/edit"
  WELCOME_MESSAGE = "Welcome to Renuo"

  command "display-name" do |c|
    c.syntax = "renuo display-name [options]"
    c.summary = "Sets the name of a customer on the Renuo dashboard"
    c.description = "Sets the name of a customer on the Renuo dashboard"
    c.example 'Display "Peter Muster" on the dashboard', 'renuo display-name "Peter Muster"'
    c.example "Remove the current name from the dashboard", "renuo display-name --delete"
    c.example "Override the current message on the dashboard", "renuo display-name Happy friday 🍻 --override"
    c.option "--delete", "Deletes the current name"
    c.option "--override", "Overrides the entire message"
    c.option "--monitor", "Open the Google slides"
    c.action { |args, options| new.run(args, options) }
  end

  def run(args, options)
    return open_path(SLIDES) if options.monitor
    return display_name(nil) if options.delete
    return say("empty argument") if args.empty?
    return run_heroku_command(args.join(" ")) if options.override

    display_name(args.join(" "))
  end

  private

  def display_name(name)
    text_message = [WELCOME_MESSAGE, name, "🥳🔥"].compact.join(" ")
    run_heroku_command(text_message)
  end

  def run_heroku_command(text_message)
    rails_command = "\"#{RENUO_CLI}['#{text_message}']\""
    run_command([HEROKU_CLI, rails_command, HEROKU_APP_NAME].join(" "))
  end
end
