# frozen_string_literal: true

class Renuo::Cli::Commands::FetchEmails
  EMAIL_LIST_URL = "https://docs.google.com/spreadsheets/d/e/2PACX-1vSqPiedBeGk0N75cxZApEohj5LrIWlHWUxTjfhkmK9aOsUltcqCn24sD1haIasUjVfd8UT8VdUKUc4h/pub?gid=703649940&single=true&output=csv"

  command "fetch-emails" do |c|
    c.syntax = "renuo fetch-emails"
    c.summary = "Retrieves all renuo employees email addresses"
    c.description = "Retrieves all renuo employees email addresses. One per line."
    c.action { new.run }
  end

  def run
    say "# Here is a complete list of Renuo email addresses".colorize :green
    say fetch_emails.join("\n")
  end

  def fetch_emails
    response = get_emails(EMAIL_LIST_URL)
    response = handle_redirection(response) if response.is_a?(Net::HTTPRedirection)
    format_response(response)
  end

  private

  def get_emails(url)
    uri = URI.parse(url)
    Net::HTTP.get_response(uri)
  end

  def handle_redirection(response)
    location = response["location"]
    get_emails(location)
  end

  def format_response(response)
    response.body.gsub("\r\n", "\n").split("\n").reject { |add| add == "n/a" }
  end
end
