# frozen_string_literal: true

class Renuo::Cli::Commands::HerokuUsers
  command "heroku-users" do |c|
    c.syntax = "renuo heroku-users add/remove emailaddress"
    c.summary = "Prints a list of commands to add or remove an email address from all Heroku projects"
    c.description = "Useful when a new person is hired or a person quits."
    c.example "renuo heroku-users add alessandro.rodi@renuo.ch",
              "Adds the user alessandro.rodi@renuo.ch to all the Heroku projects"
    c.example "renuo heroku-users remove alessandro.rodi@renuo.ch",
              "Removes the user alessandro.rodi@renuo.ch from all the Heroku projects"
    c.action { |args| new.run(args) }
  end

  def run(args)
    action, email_address = args
    abort(">> action is either add or remove") unless %w[add remove].include? action
    abort(">> specify an email address") unless email_address
    heroku_apps.each do |app|
      say "heroku access:#{action} #{email_address} --app #{app}"
    end
  end

  private

  def heroku_apps
    JSON.parse(`heroku apps --all --json`).pluck("name")
  end
end
