# frozen_string_literal: true

class Renuo::Cli::Commands::UpgradeLaptop
  command "upgrade-laptop" do |c|
    c.syntax = "renuo upgrade-laptop"
    c.summary = "Upgrades the installed apps from the app store, macOS and homebrew"
    c.description = "Upgrades the installed apps from the app store, macOS and homebrew"
    c.example "renuo upgrade-laptop", "upgrades your laptop"
    c.action { new.run }
  end

  def run
    say "Start Update"
    upgrade_apps
    upgrade_macos
    upgrade_brew unless reboot_required?
  end

  private

  def upgrade_apps
    setup_mas
    run_command "mas upgrade"
  end

  def setup_mas
    `which mas || brew install mas`
  end

  def upgrade_macos
    find_software_upgrades
    return unless upgrade_available?
    return if reboot_required_and_not_agreed_to?

    execute_upgrade
  end

  def upgrade_brew
    run_command "brew update"
    run_command "brew upgrade"
    run_command "brew cleanup"
  end

  def reboot_required?
    @output.downcase.include? "restart"
  end

  def find_software_upgrades
    say "\nUpdating  macOS.\nFinding available software (this may take a while)".yellow

    @output = `softwareupdate --list 2>&1`
    say @output
  end

  def upgrade_available?
    @output.include? "Software Update found"
  end

  def reboot_required_and_not_agreed_to?
    reboot_required? && !agree_for_reboot?
  end

  def agree_for_reboot?
    agree "\nYour Mac needs to be rebooted, Still continue?".red.to_s
  end

  def execute_upgrade
    puts `softwareupdate --install --all`
    reboot if reboot_required?
  end

  def reboot
    say "Rebooting Now".white.on_red
    say `osascript -e 'tell app "System Events" to restart'`
  end
end
