# frozen_string_literal: true

class Renuo::Cli::Services::Heroku
  class << self
    TEAMS = %w[staff renuo-legacy].freeze

    def fetch_apps
      all_app_names = TEAMS.flat_map { |team| fetch_app_names(team) }
      all_app_names += fetch_app_names # fetch apps from personal account (e.g. as collaborator)

      apps = []
      iterator = respond_to?(:progress) ? progress(all_app_names) : all_app_names
      iterator.each do |app_name|
        apps << { name: app_name, domains: fetch_domains(app_name) }
      end
      apps
    end

    def fetch_app_names(team = nil)
      fetch_app_names_cmd = %(heroku apps --json #{team ? "--team=#{team}" : ""} | jq -r '.[] | "\\(.name)"')
      stdout, stderr, status = Open3.capture3 fetch_app_names_cmd
      raise "Error fetching Heroku app list: #{stderr}" unless status.success?

      stdout.force_encoding("UTF-8").split("\n").map(&:strip)
    end

    def fetch_domains(app_name)
      fetch_domains_cmd = %(heroku domains --app #{app_name} --json | jq -r '.[] | "\\(.hostname)"')
      stdout, stderr, status = Open3.capture3 fetch_domains_cmd
      raise "Error fetching Heroku domains information: #{stderr}" unless status.success?

      stdout.force_encoding("UTF-8").split("\n").map(&:strip)
    end
  end
end
