# frozen_string_literal: true

class Renuo::Cli::Services::RenuoCliConfig
  CONFIG_FILE_PATH = "#{File.expand_path("~")}/.renuo_cli".freeze

  class << self
    def redmine_api_key
      get_config_value("REDMINE_API_KEY", "https://redmine.renuo.ch/my/account")
    end

    def toggl_api_token
      get_config_value("TOGGL_API_TOKEN", "https://toggl.com/app/profile")
    end

    private

    def get_config_value(name, open_url)
      FileUtils.touch(CONFIG_FILE_PATH)
      config = YAML.load_file(CONFIG_FILE_PATH, fallback: {})
      value = config[name]
      return value if value

      system("open #{open_url}")
      value = ask("You haven't set your #{name}, yet. Please provide one:")
      config[name] = value
      File.write(CONFIG_FILE_PATH, config.to_yaml)
      value
    end
  end
end
